==> haskell-statevar-1.2.2-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-statevar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 StateVar
version:              1.2.2
visibility:           public
id:                   StateVar-1.2.2-IRoNpZrcOkD7bHYjVlGB6n
key:                  StateVar-1.2.2-IRoNpZrcOkD7bHYjVlGB6n
license:              BSD-3-Clause
copyright:
    Copyright (C) 2014-2015 Edward A. Kmett, 2009-2021 Sven Panne

maintainer:           Sven Panne <svenpanne@gmail.com>
author:               Sven Panne and Edward Kmett
homepage:             https://github.com/haskell-opengl/StateVar
synopsis:             State variables
description:
    This package contains state variables, which are references in the IO monad,
    like IORefs or parts of the OpenGL state.

category:             Data
abi:                  45d6933574119c8d98a5f08351634049
exposed:              True
exposed-modules:      Data.StateVar
import-dirs:          /usr/lib/ghc-9.0.1/site-local/StateVar-1.2.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/StateVar-1.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/StateVar-1.2.2
hs-libraries:         HSStateVar-1.2.2-IRoNpZrcOkD7bHYjVlGB6n
depends:              base-4.15.0.0 stm-2.5.0.0 transformers-0.5.6.2
haddock-interfaces:   /usr/share/doc/haskell-statevar/html/StateVar.haddock
haddock-html:         /usr/share/doc/haskell-statevar/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-statevar-1.2.2-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-statevar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 StateVar
version:              1.2.2
visibility:           public
id:                   StateVar-1.2.2-GxMRs6UXIRXHYwZG2fj94o
key:                  StateVar-1.2.2-GxMRs6UXIRXHYwZG2fj94o
license:              BSD-3-Clause
copyright:
    Copyright (C) 2014-2015 Edward A. Kmett, 2009-2021 Sven Panne

maintainer:           Sven Panne <svenpanne@gmail.com>
author:               Sven Panne and Edward Kmett
homepage:             https://github.com/haskell-opengl/StateVar
synopsis:             State variables
description:
    This package contains state variables, which are references in the IO monad,
    like IORefs or parts of the OpenGL state.

category:             Data
abi:                  840cac63c09f23fc19388f7f33ad0da0
exposed:              True
exposed-modules:      Data.StateVar
import-dirs:          /usr/lib/ghc-9.0.2/site-local/StateVar-1.2.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/StateVar-1.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/StateVar-1.2.2
hs-libraries:         HSStateVar-1.2.2-GxMRs6UXIRXHYwZG2fj94o
depends:              base-4.15.1.0 stm-2.5.0.0 transformers-0.5.6.2
haddock-interfaces:   /usr/share/doc/haskell-statevar/html/StateVar.haddock
haddock-html:         /usr/share/doc/haskell-statevar/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
